@@ -1,8 +1,5 @@
-# -*- coding: utf-8 -*-
-
-
-class Nil(object):
-    '''Super-None, falsey and returns itself from every method/attribute/etc'''
+class Nil:
+    """Super-None, falsey and returns itself from every method/attribute/etc"""
 
     def __repr__(self):
         return "Nil()"
@@ -22,7 +19,7 @@ class Nil(object):
     def __setitem__(self, key, val):
         return self
 
-    def __delitem__(self, key, val):
+    def __delitem__(self, key):
         return self
 
     def __getattr__(self, name):
@@ -31,7 +28,7 @@ class Nil(object):
     def __setattr__(self, name, value):
         return self
 
-    def __delattr__(self, name, value):
+    def __delattr__(self, name):
         return self
 
     def __eq__(self, other):
@@ -40,4 +37,4 @@ class Nil(object):
         return False
 
     def __iter__(self):
-        return iter([])
\ No newline at end of file
+        return iter([])
