@@ -1,11 +1,10 @@
-# -*- coding: utf-8 -*-
-
 import collections
-import io
-import lxml
 import os
 import re
 
+import lxml
+
+
 def englishFromList(items, conjunction="or"):
     # Format a list of strings into an English list.
     items = list(items)
@@ -25,30 +24,30 @@ def intersperse(iterable, delimiter):
 
 
 def processTextNodes(nodes, regex, replacer):
-    '''
+    """
     Takes an array of alternating text/objects,
     and runs reSubObject on the text parts,
     splicing them into the passed-in array.
     Mutates!
-    '''
+    """
     for i, node in enumerate(nodes):
         # Node list always alternates between text and elements
         if i % 2 == 0:
-            nodes[i:i + 1] = reSubObject(regex, node, replacer)
+            nodes[i : i + 1] = reSubObject(regex, node, replacer)
     return nodes
 
 
 def reSubObject(pattern, string, repl=None):
-    '''
+    """
     like re.sub, but replacements don't have to be text;
     returns an array of alternating unmatched text and match objects instead.
     If repl is specified, it's called with each match object,
     and the result then shows up in the array instead.
-    '''
+    """
     lastEnd = 0
     pieces = []
     for match in pattern.finditer(string):
-        pieces.append(string[lastEnd:match.start()])
+        pieces.append(string[lastEnd : match.start()])
         if repl:
             pieces.append(repl(match))
         else:
@@ -71,41 +70,43 @@ def simplifyText(text):
     return text
 
 
-def linkTextsFromElement(el, preserveCasing=False):
+def linkTextsFromElement(el):
     from ..h import find, textContent
-    if el.get('data-lt') == '':
+
+    if el.get("data-lt") == "":
         return []
-    elif el.get('data-lt'):
-        rawText = el.get('data-lt')
+    elif el.get("data-lt"):
+        rawText = el.get("data-lt")
         if rawText in ["|", "||", "|||"]:
             texts = [rawText]
         else:
-            texts = [x.strip() for x in rawText.split('|')]
+            texts = [x.strip() for x in rawText.split("|")]
     else:
         if el.tag in ("dfn", "a"):
             texts = [textContent(el).strip()]
         elif el.tag in ("h2", "h3", "h4", "h5", "h6"):
             texts = [textContent(find(".content", el)).strip()]
-    if el.get('data-local-lt'):
-        localTexts = [x.strip() for x in el.get('data-local-lt').split('|')]
+    if el.get("data-local-lt"):
+        localTexts = [x.strip() for x in el.get("data-local-lt").split("|")]
         for text in localTexts:
             if text in texts:
                 # lt and local-lt both specify the same thing
                 raise DuplicatedLinkText(text, texts + localTexts, el)
         texts += localTexts
 
-    texts = [re.sub(r"\s+", " ", x) for x in texts if x != '']
+    texts = [re.sub(r"\s+", " ", x) for x in texts if x != ""]
     return texts
 
 
 class DuplicatedLinkText(Exception):
     def __init__(self, offendingText, allTexts, el):
+        super().__init__()
         self.offendingText = offendingText
         self.allTexts = allTexts
         self.el = el
 
     def __unicode__(self):
-        return "<Text '{0}' shows up in both lt and local-lt>".format(self.offendingText)
+        return f"<Text '{self.offendingText}' shows up in both lt and local-lt>"
 
 
 def firstLinkTextFromElement(el):
@@ -113,23 +114,27 @@ def firstLinkTextFromElement(el):
         texts = linkTextsFromElement(el)
     except DuplicatedLinkText as e:
         texts = e.allTexts
-    return texts[0] if len(texts) else None
+    return texts[0] if len(texts) > 0 else None
 
 
 def splitForValues(forValues):
-    '''
+    """
     Splits a string of 1+ "for" values into an array of individual value.
     Respects function args, etc.
     Currently, for values are separated by commas.
-    '''
+    """
     if forValues is None:
         return None
-    forValues = re.sub("\s+", " ", forValues)
-    return [value.strip() for value in re.split(r',(?![^()]*\))', forValues) if value.strip()]
+    forValues = re.sub(r"\s+", " ", forValues)
+    return [
+        value.strip()
+        for value in re.split(r",(?![^()]*\))", forValues)
+        if value.strip()
+    ]
 
 
 def groupFromKey(key, length=2):
-    '''Generates a filename-safe "group" from a key, of a specified length.'''
+    """Generates a filename-safe "group" from a key, of a specified length."""
     if key in _groupFromKeyCache:
         return _groupFromKeyCache[key]
     safeChars = frozenset("abcdefghijklmnopqrstuvwxyz0123456789")
@@ -144,14 +149,19 @@ def groupFromKey(key, length=2):
         group = group.ljust(length, "_")
         _groupFromKeyCache[key] = group
         return group
+
+
 _groupFromKeyCache = {}
 
 
-def flatten(l):
-    for el in l:
-        if isinstance(el, collections.Iterable) and not isinstance(el, str) and not lxml.etree.iselement(el):
-            for sub in flatten(el):
-                yield sub
+def flatten(arr):
+    for el in arr:
+        if (
+            isinstance(el, collections.Iterable)
+            and not isinstance(el, str)
+            and not lxml.etree.iselement(el)
+        ):
+            yield from flatten(el)
         else:
             yield el
 
@@ -170,6 +180,7 @@ def doEvery(s, action, lastTime=None):
     # pass 0 as lastTime;
     # otherwise it won't take action until N seconds.
     import time
+
     newTime = time.time()
     if lastTime is None:
         lastTime = newTime
