@@ -1,9 +1,6 @@
-# -*- coding: utf-8 -*-
-import io
 import json
-import os
 from collections import OrderedDict
-from . import config
+
 from .h import *  # noqa
 from .messages import *
 
@@ -13,18 +10,20 @@ def addMdnPanels(doc):
         return
 
     try:
-        filename = doc.md.vshortname+".json"
+        filename = doc.md.vshortname + ".json"
         datafile = doc.dataFile.fetch("mdn", filename, str=True)
-    except IOError:
+    except OSError:
         try:
-            filename = doc.md.shortname+".json"
+            filename = doc.md.shortname + ".json"
             datafile = doc.dataFile.fetch("mdn", filename, str=True)
-        except IOError:
+        except OSError:
             if doc.md.includeMdnPanels == "maybe":
                 # if "maybe", failure is fine, don't complain
                 pass
             else:
-                die(f"Couldn't find the MDN data for '{doc.md.vshortname}' nor '{doc.md.shortname}'.")
+                die(
+                    f"Couldn't find the MDN data for '{doc.md.vshortname}' nor '{doc.md.shortname}'."
+                )
             return
     try:
         data = json.loads(datafile, object_pairs_hook=OrderedDict)
@@ -34,14 +33,18 @@ def addMdnPanels(doc):
 
     panels = panelsFromData(doc, data)
     if panels:
-        doc.extraScripts["script-mdn-anno"] = '''
+        doc.extraScripts[
+            "script-mdn-anno"
+        ] = """
             document.body.addEventListener("click", (e) => {
                 if(e.target.closest(".mdn-anno-btn")) {
                     e.target.closest(".mdn-anno").classList.toggle("wrapped");
                 }
             });
-            '''  # noqa
-        doc.extraStyles["style-mdn-anno"] = '''
+            """  # noqa
+        doc.extraStyles[
+            "style-mdn-anno"
+        ] = """
             @media (max-width: 767px) { .mdn-anno { opacity: .1 } }
             .mdn-anno { font: 1em sans-serif; padding: 0.3em; position: absolute; z-index: 8; right: 0.3em; background: #EEE; color: black; box-shadow: 0 0 3px #999; overflow: hidden; border-collapse: initial; border-spacing: initial; min-width: 9em; max-width: min-content; white-space: nowrap; word-wrap: normal; hyphens: none}
             .mdn-anno:not(.wrapped) { opacity: 1}
@@ -95,21 +98,27 @@ def addMdnPanels(doc):
             h4 + .mdn-anno.after { margin: -42px 0 0 0; }
             h5 + .mdn-anno.after { margin: -40px 0 0 0; }
             h6 + .mdn-anno.after { margin: -40px 0 0 0; }
-            '''  # noqa
+            """  # noqa
+
 
 def createAnno(className, mdnButton, featureDivs):
     return E.div({"class": className}, mdnButton, featureDivs)
 
+
 def panelsFromData(doc, data):
     mdnBaseUrl = "https://developer.mozilla.org/en-US/docs/Web/"
-    bcdBaseUrl = "https://github.com/mdn/browser-compat-data/blob/master/"
 
     browsersProvidingCurrentEngines = ["firefox", "safari", "chrome"]
     browsersWithBorrowedEngines = ["opera", "edge_blink"]
     browsersWithRetiredEngines = ["edge", "ie"]
-    browsersForMobileDevices = ["firefox_android", "safari_ios",
-                                "chrome_android", "webview_android",
-                                "samsunginternet_android", "opera_android"]
+    browsersForMobileDevices = [
+        "firefox_android",
+        "safari_ios",
+        "chrome_android",
+        "webview_android",
+        "samsunginternet_android",
+        "opera_android",
+    ]
 
     # BCD/mdn-spec-links shortnames to full names
     nameFromCodeName = {
@@ -126,7 +135,7 @@ def panelsFromData(doc, data):
         "safari": "Safari",
         "samsunginternet_android": "Samsung Internet",
         "safari_ios": "iOS Safari",
-        "webview_android": "Android WebView"
+        "webview_android": "Android WebView",
     }
 
     panels = False
@@ -139,26 +148,36 @@ def panelsFromData(doc, data):
         featureDivs = []
         targetElement = find(f"[id='{elementId}']", doc)
         if targetElement is None:
-            warn(f"No '{elementId}' ID found, skipping MDN features that would target it.")
+            warn(
+                f"No '{elementId}' ID found, skipping MDN features that would target it."
+            )
             continue
+
+        panels = True
+        if targetElement.tag in ["h1", "h2", "h3", "h4", "h5", "h6"]:
+            isAnnoForHeadingContent = True
         else:
-            panels = True
-            if targetElement.tag in ['h1', 'h2', 'h3', 'h4', 'h5', 'h6']:
-                isAnnoForHeadingContent = True
-            else:
-                for ancestor in targetElement.iterancestors():
-                    if ancestor.tag in ['body', 'main', 'article', 'aside',
-                                        'nav', 'section', 'header', 'footer']:
-                        break
-                    targetElement = ancestor
-                    if ancestor.tag in ['h1', 'h2', 'h3', 'h4', 'h5', 'h6']:
-                        isAnnoForHeadingContent = True
-                        break
-                    if ancestor.tag in ['td', 'dt', 'dd', 'li']:
-                        isAnnoForListItemOrTableContent = True
-                        break
-                    if ancestor.tag in ['pre', 'xmp', 'p']:
-                        break
+            for ancestor in targetElement.iterancestors():
+                if ancestor.tag in [
+                    "body",
+                    "main",
+                    "article",
+                    "aside",
+                    "nav",
+                    "section",
+                    "header",
+                    "footer",
+                ]:
+                    break
+                targetElement = ancestor
+                if ancestor.tag in ["h1", "h2", "h3", "h4", "h5", "h6"]:
+                    isAnnoForHeadingContent = True
+                    break
+                if ancestor.tag in ["td", "dt", "dd", "li"]:
+                    isAnnoForListItemOrTableContent = True
+                    break
+                if ancestor.tag in ["pre", "xmp", "p"]:
+                    break
         for feature in features:
             if "engines" in feature:
                 engines = len(feature["engines"])
@@ -172,30 +191,44 @@ def panelsFromData(doc, data):
                 mdnPanelFor(
                     feature,
                     mdnBaseUrl,
-                    bcdBaseUrl,
                     nameFromCodeName,
                     browsersProvidingCurrentEngines,
                     browsersWithBorrowedEngines,
                     browsersWithRetiredEngines,
-                    browsersForMobileDevices))
+                    browsersForMobileDevices,
+                )
+            )
 
         mdnButton = E.button({"class": "mdn-anno-btn"})
         if lessThanTwoEngines > 0:
-            appendChild(mdnButton,
-                E.b({"class": "less-than-two-engines-flag",
-                     "title": "This feature is in less than two current engines."},
-                    "\u26A0"))
+            appendChild(
+                mdnButton,
+                E.b(
+                    {
+                        "class": "less-than-two-engines-flag",
+                        "title": "This feature is in less than two current engines.",
+                    },
+                    "\u26A0",
+                ),
+            )
         elif allEngines > 0 and lessThanTwoEngines == 0 and onlyTwoEngines == 0:
-            appendChild(mdnButton,
-                E.b({"class": "all-engines-flag",
-                     "title": "This feature is in all current engines."},
-                    "\u2714"))
+            appendChild(
+                mdnButton,
+                E.b(
+                    {
+                        "class": "all-engines-flag",
+                        "title": "This feature is in all current engines.",
+                    },
+                    "\u2714",
+                ),
+            )
         appendChild(mdnButton, E.span("MDN"))
 
         className = "mdn-anno wrapped"
         if isAnnoForListItemOrTableContent:
-            if targetElement.getchildren() \
-                    and hasClass(targetElement.getchildren()[0], 'mdn-anno'):
+            if targetElement.getchildren() and hasClass(
+                targetElement.getchildren()[0], "mdn-anno"
+            ):
                 # If there's already an annotation at the point where we want
                 # this, just re-use it (instead of creating another one).
                 appendChild(targetElement.getchildren()[0], featureDivs)
@@ -205,21 +238,29 @@ def panelsFromData(doc, data):
                 # cases where we have a long table or list, all the annotations
                 # for everything in it otherwise ends up being merged into a
                 # single annotation way up at the top of the table or list.
-                prependChild(targetElement, createAnno(className, mdnButton, featureDivs))
+                prependChild(
+                    targetElement, createAnno(className, mdnButton, featureDivs)
+                )
         elif isAnnoForHeadingContent:
             className = "mdn-anno wrapped after"
-            if targetElement.getnext() is not None \
-                    and targetElement.getnext().get('class') == className:
+            if (
+                targetElement.getnext() is not None
+                and targetElement.getnext().get("class") == className
+            ):
                 # If there's already an annotation at the point where we want
                 # this, just re-use it (instead of creating another one).
                 appendChild(targetElement.getnext(), featureDivs)
             else:
                 # For elements we're annotating inside an h1-h6 heading, we
                 # insert the annotation as the next sibling of the heading.
-                insertAfter(targetElement, createAnno(className, mdnButton, featureDivs))
+                insertAfter(
+                    targetElement, createAnno(className, mdnButton, featureDivs)
+                )
         else:
-            if targetElement.getprevious() is not None \
-                    and targetElement.getprevious().get('class') == className:
+            if (
+                targetElement.getprevious() is not None
+                and targetElement.getprevious().get("class") == className
+            ):
                 # If there's already an annotation at the point where we want
                 # this, just re-use it (instead of creating another one) —
                 # unless it's a class=after annotation (following a heading).
@@ -228,9 +269,12 @@ def panelsFromData(doc, data):
                 # For elements we're annotating that aren't inside a table or
                 # list or heading, we insert the annotation as the previous
                 # sibling of whatever block-level element holds the element.
-                insertBefore(targetElement, createAnno(className, mdnButton, featureDivs))
+                insertBefore(
+                    targetElement, createAnno(className, mdnButton, featureDivs)
+                )
     return panels
 
+
 def addSupportRow(browserCodeName, nameFromCodeName, support, supportData):
     if browserCodeName not in support:
         return
@@ -246,9 +290,11 @@ def addSupportRow(browserCodeName, nameFromCodeName, support, supportData):
             versionAdded = thisBrowserSupport["version_added"]
             if "flags" in thisBrowserSupport:
                 needsFlag = True
-            if "prefix" in thisBrowserSupport or \
-                    'alternative_name' in thisBrowserSupport or \
-                    'partial_implementation' in thisBrowserSupport:
+            if (
+                "prefix" in thisBrowserSupport
+                or "alternative_name" in thisBrowserSupport
+                or "partial_implementation" in thisBrowserSupport
+            ):
                 versionAdded = False
         if "version_removed" in thisBrowserSupport:
             versionRemoved = thisBrowserSupport["version_removed"]
@@ -264,9 +310,11 @@ def addSupportRow(browserCodeName, nameFromCodeName, support, supportData):
                 if versionDetails["version_added"] is None:
                     versionAdded = None
                     continue
-                if "prefix" in versionDetails or \
-                        'alternative_name' in versionDetails or \
-                        'partial_implementation' in versionDetails:
+                if (
+                    "prefix" in versionDetails
+                    or "alternative_name" in versionDetails
+                    or "partial_implementation" in versionDetails
+                ):
                     continue
                 if "flags" in thisBrowserSupport:
                     needsFlag = True
@@ -285,51 +333,56 @@ def addSupportRow(browserCodeName, nameFromCodeName, support, supportData):
         if versionRemoved is None:
             statusCode = "y"
             minVersion = versionAdded + "+"
-            if (isEdgeLegacy and versionAdded == "18"):
+            if isEdgeLegacy and versionAdded == "18":
                 minVersion = "18"
-            if (isIE and versionAdded == "11"):
+            if isIE and versionAdded == "11":
                 minVersion = "11"
         else:
             statusCode = "n"
             if versionAdded is not None:
-                minVersion = versionAdded + u"\u2013" + versionRemoved
+                minVersion = versionAdded + "\u2013" + versionRemoved
             else:
                 minVersion = "None"
     browserFullName = nameFromCodeName[browserCodeName]
-    appendChild(supportData,
+    appendChild(
+        supportData,
         browserCompatSpan(
-            browserCodeName,
-            browserFullName,
-            statusCode,
-            minVersion,
-            needsFlag))
+            browserCodeName, browserFullName, statusCode, minVersion, needsFlag
+        ),
+    )
 
 
-def mdnPanelFor(feature, mdnBaseUrl, bcdBaseUrl, nameFromCodeName,
-                browsersProvidingCurrentEngines, browsersWithBorrowedEngines,
-                browsersWithRetiredEngines, browsersForMobileDevices):
+def mdnPanelFor(
+    feature,
+    mdnBaseUrl,
+    nameFromCodeName,
+    browsersProvidingCurrentEngines,
+    browsersWithBorrowedEngines,
+    browsersWithRetiredEngines,
+    browsersForMobileDevices,
+):
     featureDiv = E.div({"class": "feature"})
-    featureName = feature.get("name", None)
     if "slug" in feature:
         slug = feature["slug"]
         displaySlug = slug.split("/", 1)[1]
         title = feature.get("summary", "")
         mdnURL = mdnBaseUrl + slug
-        appendChild(featureDiv,
-            E.p({},
-                E.a({"href": mdnURL, "title": title}, displaySlug)))
+        appendChild(
+            featureDiv, E.p({}, E.a({"href": mdnURL, "title": title}, displaySlug))
+        )
     if "engines" in feature:
         engines = len(feature["engines"])
         enginesPara = None
         if engines == 0:
-            enginesPara = E.p({"class": "less-than-two-engines-text"},
-                              "In no current engines.")
+            enginesPara = E.p(
+                {"class": "less-than-two-engines-text"}, "In no current engines."
+            )
         elif engines == 1:
-            enginesPara = E.p({"class": "less-than-two-engines-text"},
-                              "In only one current engine.")
+            enginesPara = E.p(
+                {"class": "less-than-two-engines-text"}, "In only one current engine."
+            )
         elif engines >= len(browsersProvidingCurrentEngines):
-            enginesPara = E.p({"class": "all-engines-text"},
-                              "In all current engines.")
+            enginesPara = E.p({"class": "all-engines-text"}, "In all current engines.")
         if enginesPara is not None:
             appendChild(featureDiv, enginesPara)
     supportData = E.div({"class": "support"})
@@ -352,16 +405,18 @@ def mdnPanelFor(feature, mdnBaseUrl, bcdBaseUrl, nameFromCodeName,
     return featureDiv
 
 
-def browserCompatSpan(browserCodeName, browserFullName, statusCode, minVersion,
-                      needsFlag):
+def browserCompatSpan(
+    browserCodeName, browserFullName, statusCode, minVersion, needsFlag
+):
     # browserCodeName: e.g. "chrome"
     # browserFullName: e.g. "Chrome for Android"
     minVersionAttributes = {}
     flagSymbol = ""
     if needsFlag:
         flagSymbol = "\U0001f530 "
-        minVersionAttributes["title"] = \
-            "Requires setting a user preference or runtime flag."
+        minVersionAttributes[
+            "title"
+        ] = "Requires setting a user preference or runtime flag."
     statusClass = {"y": "yes", "n": "no"}[statusCode]
     outer = E.span({"class": browserCodeName + " " + statusClass})
     appendChild(outer, E.span({}, browserFullName))
